@@ -130,7 +130,12 @@ class TestFeaturizer(unittest.TestCase):
         inds = self.feat.select_Backbone()
     
     def test_select_non_symmetry_heavy_atoms(self):
-        inds = self.feat.select_Heavy(exclude_symmetry_related=True)
+        try:
+            inds = self.feat.select_Heavy(exclude_symmetry_related=True)
+        except RuntimeError as e:
+            if "recursion depth" in e.args:
+                import sys
+                raise Exception("recursion limit reached. Interpreter limit: {}".format(sys.getrecursionlimit()))
 
     def test_select_all(self):
         self.feat.add_all()
@@ -308,7 +313,6 @@ class TestFeaturizer(unittest.TestCase):
         assert(np.alltrue(Y <= np.pi))
         self.assertEqual(len(self.feat.describe()), self.feat.dimension())
 
-
     def test_angles_deg(self):
         sel = np.array([[1, 2, 5],
                         [1, 3, 8],
@@ -326,6 +330,7 @@ class TestFeaturizer(unittest.TestCase):
         self.feat.add_angles(sel, cossin=True)
         assert(self.feat.dimension() == 2 * sel.shape[0])
         Y = self.feat.transform(self.traj)
+        self.assertEqual(Y.shape, (self.traj.n_frames, 2*sel.shape[0]))
         assert(np.alltrue(Y >= -np.pi))
         assert(np.alltrue(Y <= np.pi))
 
@@ -848,7 +853,43 @@ class TestCustomFeature(unittest.TestCase):
                                   self.means,
                                   self.U
                                   )
-        self.feat.describe()
+        desc = self.feat.describe()
+        self.assertEqual(len(desc), self.feat.dimension())
+
+    def test_describe_given(self):
+        self.feat.add_custom_func(some_call_to_mdtraj_some_operations_some_linalg, self.U.shape[1],
+                                  self.pairs,
+                                  self.means,
+                                  self.U, description=['foo']*self.U.shape[1]
+                                  )
+        desc = self.feat.describe()
+        self.assertIn('foo', desc)
+        self.assertEqual(len(desc), self.feat.dimension())
+
+    def test_describe_given_str(self):
+        self.feat.add_custom_func(some_call_to_mdtraj_some_operations_some_linalg, self.U.shape[1],
+                                  self.pairs,
+                                  self.means,
+                                  self.U, description='test')
+        desc = self.feat.describe()
+        self.assertIn('test', desc)
+        self.assertEqual(len(desc), self.feat.dimension())
+
+    def test_describe_given_wrong(self):
+        """ either a list matching input dim, or 1 element iterable allowed"""
+        with self.assertRaises(ValueError) as cm:
+            self.feat.add_custom_func(some_call_to_mdtraj_some_operations_some_linalg, self.U.shape[1]+1,
+                                      self.pairs,
+                                      self.means,
+                                      self.U, description=['ff', 'ff'])
+
+    def test_describe_1_element_expand(self):
+        self.feat.add_custom_func(some_call_to_mdtraj_some_operations_some_linalg, self.U.shape[1] + 1,
+                                  self.pairs,
+                                  self.means,
+                                  self.U, description=['test'])
+        desc = self.feat.describe()
+        self.assertEqual(desc, ['test']*3)
 
     def test_dimensionality(self):
         self.feat.add_custom_func(some_call_to_mdtraj_some_operations_some_linalg, self.U.shape[1],
